# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: interface.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 0, "", "interface.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import xaudio.protocol.nanopb_pb2 as nanopb__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0finterface.proto\x1a\x0cnanopb.proto",\n\x0cResetRequest\x12\x12\n\x05\x64ummy\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x08\n\x06_dummy"-\n\rStatusRequest\x12\x12\n\x05\x64ummy\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x08\n\x06_dummy"2\n\x12\x41\x32\x42\x44iscoverRequest\x12\x12\n\x05\x64ummy\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x08\n\x06_dummy"+\n\x0bInfoRequest\x12\x12\n\x05\x64ummy\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x08\n\x06_dummy"E\n\x10SetSerialRequest\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x11\n\x04lock\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x07\n\x05_lock"\xe8\x01\n\x16I2COverDistanceRequest\x12/\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\x0e\x32\x1a.I2COverDistanceAccessType\x12 \n\x13peripheral_i2c_addr\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x0c\n\x04node\x18\x03 \x01(\r\x12\x31\n\x04\x64\x61ta\x18\x06 \x03(\x0b\x32\x1c.I2COverDistanceRequest.DataB\x05\x92?\x02\x10\n\x1a"\n\x04\x44\x61ta\x12\x0b\n\x03reg\x18\x04 \x01(\r\x12\r\n\x05value\x18\x05 \x01(\rB\x16\n\x14_peripheral_i2c_addr"`\n\x17I2COverDistanceResponse\x12/\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\x0e\x32\x1a.I2COverDistanceAccessType\x12\x14\n\x05value\x18\x02 \x03(\rB\x05\x92?\x02\x10\n"\x8d\x01\n\x19\x41\x32\x42MailboxTransferRequest\x12\x12\n\nmailbox_id\x18\x01 \x01(\r\x12*\n\x0b\x61\x63\x63\x65ss_type\x18\x02 \x01(\x0e\x32\x15.A2BMailboxAccessType\x12\x0c\n\x04node\x18\x03 \x01(\r\x12\r\n\x05\x62ytes\x18\x04 \x01(\r\x12\x13\n\x04\x64\x61ta\x18\x05 \x03(\rB\x05\x92?\x02\x10\x04"\xa1\x01\n\x1a\x41\x32\x42MailboxTransferResponse\x12\x12\n\nmailbox_id\x18\x01 \x01(\r\x12*\n\x0b\x61\x63\x63\x65ss_type\x18\x02 \x01(\x0e\x32\x15.A2BMailboxAccessType\x12.\n\raccess_status\x18\x03 \x01(\x0e\x32\x17.A2BMailboxAccessStatus\x12\x13\n\x04\x64\x61ta\x18\x04 \x03(\rB\x05\x92?\x02\x10\x04".\n\x0eNoDataResponse\x12\x12\n\x05\x64ummy\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x08\n\x06_dummy"\xf5\x01\n\x17StatusRespRoleA2BMaster\x12\x1d\n\x15\x61\x32\x62_slaves_discovered\x18\x01 \x01(\r\x12\x39\n\ta2b_fault\x18\x02 \x01(\x0b\x32!.StatusRespRoleA2BMaster.A2bFaultH\x00\x88\x01\x01\x1ar\n\x08\x41\x32\x62\x46\x61ult\x12\r\n\x05\x66\x61ult\x18\x01 \x01(\r\x12#\n\x08location\x18\x02 \x01(\x0e\x32\x11.A2BFaultLocation\x12\x1d\n\x10slave_with_fault\x18\x03 \x01(\rH\x00\x88\x01\x01\x42\x13\n\x11_slave_with_faultB\x0c\n\n_a2b_fault";\n\x16StatusRespRoleA2BSlave\x12!\n\ta2b_state\x18\x01 \x01(\x0e\x32\x0e.SlaveA2BState"\xc3\x02\n\x0eStatusResponse\x12\x38\n\x1ausb_audio_downstream_state\x18\x01 \x01(\x0e\x32\x14.UsbAudioStreamState\x12\x36\n\x18usb_audio_upstream_state\x18\x02 \x01(\x0e\x32\x14.UsbAudioStreamState\x12"\n\x0c\x64\x65vice_state\x18\x03 \x01(\x0e\x32\x0c.DeviceState\x12+\n\x11\x63onfig_json_state\x18\x04 \x01(\x0e\x32\x10.ConfigJsonState\x12\x31\n\rstatus_master\x18\x05 \x01(\x0b\x32\x18.StatusRespRoleA2BMasterH\x00\x12/\n\x0cstatus_slave\x18\x06 \x01(\x0b\x32\x17.StatusRespRoleA2BSlaveH\x00\x42\n\n\x08oneofmsg"[\n\x0cInfoResponse\x12\x19\n\x11hardware_revision\x18\x01 \x01(\r\x12\x19\n\x11software_revision\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\t"\xa5\x02\n\x10PositiveResponse\x12+\n\x10no_data_response\x18\x01 \x01(\x0b\x32\x0f.NoDataResponseH\x00\x12*\n\x0fstatus_response\x18\x02 \x01(\x0b\x32\x0f.StatusResponseH\x00\x12&\n\rinfo_response\x18\x03 \x01(\x0b\x32\r.InfoResponseH\x00\x12>\n\x1ai2c_over_distance_response\x18\x04 \x01(\x0b\x32\x18.I2COverDistanceResponseH\x00\x12\x44\n\x1d\x61\x32\x62_mailbox_transfer_response\x18\x05 \x01(\x0b\x32\x1b.A2BMailboxTransferResponseH\x00\x42\n\n\x08oneofmsg"G\n\x10NegativeResponse\x12\x11\n\x07no_data\x18\x01 \x01(\x08H\x00\x12\x14\n\ntext_error\x18\x02 \x01(\tH\x00\x42\n\n\x08oneofmsg"\xfb\x02\n\rRequestPacket\x12&\n\rreset_request\x18\x01 \x01(\x0b\x32\r.ResetRequestH\x00\x12\x33\n\x14\x61\x32\x62_discover_request\x18\x02 \x01(\x0b\x32\x13.A2BDiscoverRequestH\x00\x12(\n\x0estatus_request\x18\x03 \x01(\x0b\x32\x0e.StatusRequestH\x00\x12$\n\x0cinfo_request\x18\x04 \x01(\x0b\x32\x0c.InfoRequestH\x00\x12/\n\x12set_serial_request\x18\x05 \x01(\x0b\x32\x11.SetSerialRequestH\x00\x12<\n\x19i2c_over_distance_request\x18\x06 \x01(\x0b\x32\x17.I2COverDistanceRequestH\x00\x12\x42\n\x1c\x61\x32\x62_mailbox_transfer_request\x18\x07 \x01(\x0b\x32\x1a.A2BMailboxTransferRequestH\x00\x42\n\n\x08oneofmsg"|\n\x0eResponsePacket\x12.\n\x11positive_response\x18\x01 \x01(\x0b\x32\x11.PositiveResponseH\x00\x12.\n\x11negative_response\x18\x02 \x01(\x0b\x32\x11.NegativeResponseH\x00\x42\n\n\x08oneofmsg*s\n\x10\x41\x32\x42\x46\x61ultLocation\x12"\n\x1e\x41\x32\x42_FAULT_LOCATION_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x41\x32\x42_FAULT_LOCATION_MASTER\x10\x01\x12\x1c\n\x18\x41\x32\x42_FAULT_LOCATION_SLAVE\x10\x02*\xa7\x01\n\rSlaveA2BState\x12\x1f\n\x1bSLAVE_A2B_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14SLAVE_A2B_STATE_INIT\x10\x01\x12!\n\x1dSLAVE_A2B_STATE_WAIT_DISCOVER\x10\x02\x12\x19\n\x15SLAVE_A2B_STATE_READY\x10\x03\x12\x1d\n\x19SLAVE_A2B_STATE_NOT_READY\x10\x04*\x84\x01\n\x13UsbAudioStreamState\x12&\n"USB_AUDIO_STREAM_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bUSB_AUDIO_STREAM_STATE_IDLE\x10\x01\x12$\n USB_AUDIO_STREAM_STATE_STREAMING\x10\x02*\x8e\x01\n\x0b\x44\x65viceState\x12\x1c\n\x18\x44\x45VICE_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x44\x45VICE_STATE_BOOT\x10\x01\x12\x17\n\x13\x44\x45VICE_STATE_NORMAL\x10\x02\x12\x19\n\x15\x44\x45VICE_STATE_IMPAIRED\x10\x03\x12\x16\n\x12\x44\x45VICE_STATE_ERROR\x10\x04*w\n\x19I2COverDistanceAccessType\x12!\n\x1dI2C_OVER_DISTANCE_UNSPECIFIED\x10\x00\x12\x1b\n\x17I2C_OVER_DISTANCE_WRITE\x10\x01\x12\x1a\n\x16I2C_OVER_DISTANCE_READ\x10\x02*p\n\x0f\x43onfigJsonState\x12!\n\x1d\x43ONFIG_JSON_STATE_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONFIG_JSON_STATE_VALID\x10\x01\x12\x1d\n\x19\x43ONFIG_JSON_STATE_INVALID\x10\x02*\x84\x01\n\x14\x41\x32\x42MailboxAccessType\x12\'\n#A2B_MAILBOX_ACCESS_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1d\x41\x32\x42_MAILBOX_ACCESS_TYPE_WRITE\x10\x01\x12 \n\x1c\x41\x32\x42_MAILBOX_ACCESS_TYPE_READ\x10\x02*\xbf\x01\n\x16\x41\x32\x42MailboxAccessStatus\x12"\n\x1e\x41\x32\x42_MAILBOX_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x41\x32\x42_MAILBOX_STATUS_OK\x10\x01\x12#\n\x1f\x41\x32\x42_MAILBOX_STATUS_GENERAL_FAIL\x10\x02\x12 \n\x1c\x41\x32\x42_MAILBOX_STATUS_NOT_EMPTY\x10\x03\x12\x1f\n\x1b\x41\x32\x42_MAILBOX_STATUS_NOT_FULL\x10\x04\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "interface_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_I2COVERDISTANCEREQUEST"].fields_by_name["data"]._loaded_options = None
    _globals["_I2COVERDISTANCEREQUEST"].fields_by_name[
        "data"
    ]._serialized_options = b"\222?\002\020\n"
    _globals["_I2COVERDISTANCERESPONSE"].fields_by_name["value"]._loaded_options = None
    _globals["_I2COVERDISTANCERESPONSE"].fields_by_name[
        "value"
    ]._serialized_options = b"\222?\002\020\n"
    _globals["_A2BMAILBOXTRANSFERREQUEST"].fields_by_name["data"]._loaded_options = None
    _globals["_A2BMAILBOXTRANSFERREQUEST"].fields_by_name[
        "data"
    ]._serialized_options = b"\222?\002\020\004"
    _globals["_A2BMAILBOXTRANSFERRESPONSE"].fields_by_name[
        "data"
    ]._loaded_options = None
    _globals["_A2BMAILBOXTRANSFERRESPONSE"].fields_by_name[
        "data"
    ]._serialized_options = b"\222?\002\020\004"
    _globals["_A2BFAULTLOCATION"]._serialized_start = 2588
    _globals["_A2BFAULTLOCATION"]._serialized_end = 2703
    _globals["_SLAVEA2BSTATE"]._serialized_start = 2706
    _globals["_SLAVEA2BSTATE"]._serialized_end = 2873
    _globals["_USBAUDIOSTREAMSTATE"]._serialized_start = 2876
    _globals["_USBAUDIOSTREAMSTATE"]._serialized_end = 3008
    _globals["_DEVICESTATE"]._serialized_start = 3011
    _globals["_DEVICESTATE"]._serialized_end = 3153
    _globals["_I2COVERDISTANCEACCESSTYPE"]._serialized_start = 3155
    _globals["_I2COVERDISTANCEACCESSTYPE"]._serialized_end = 3274
    _globals["_CONFIGJSONSTATE"]._serialized_start = 3276
    _globals["_CONFIGJSONSTATE"]._serialized_end = 3388
    _globals["_A2BMAILBOXACCESSTYPE"]._serialized_start = 3391
    _globals["_A2BMAILBOXACCESSTYPE"]._serialized_end = 3523
    _globals["_A2BMAILBOXACCESSSTATUS"]._serialized_start = 3526
    _globals["_A2BMAILBOXACCESSSTATUS"]._serialized_end = 3717
    _globals["_RESETREQUEST"]._serialized_start = 33
    _globals["_RESETREQUEST"]._serialized_end = 77
    _globals["_STATUSREQUEST"]._serialized_start = 79
    _globals["_STATUSREQUEST"]._serialized_end = 124
    _globals["_A2BDISCOVERREQUEST"]._serialized_start = 126
    _globals["_A2BDISCOVERREQUEST"]._serialized_end = 176
    _globals["_INFOREQUEST"]._serialized_start = 178
    _globals["_INFOREQUEST"]._serialized_end = 221
    _globals["_SETSERIALREQUEST"]._serialized_start = 223
    _globals["_SETSERIALREQUEST"]._serialized_end = 292
    _globals["_I2COVERDISTANCEREQUEST"]._serialized_start = 295
    _globals["_I2COVERDISTANCEREQUEST"]._serialized_end = 527
    _globals["_I2COVERDISTANCEREQUEST_DATA"]._serialized_start = 469
    _globals["_I2COVERDISTANCEREQUEST_DATA"]._serialized_end = 503
    _globals["_I2COVERDISTANCERESPONSE"]._serialized_start = 529
    _globals["_I2COVERDISTANCERESPONSE"]._serialized_end = 625
    _globals["_A2BMAILBOXTRANSFERREQUEST"]._serialized_start = 628
    _globals["_A2BMAILBOXTRANSFERREQUEST"]._serialized_end = 769
    _globals["_A2BMAILBOXTRANSFERRESPONSE"]._serialized_start = 772
    _globals["_A2BMAILBOXTRANSFERRESPONSE"]._serialized_end = 933
    _globals["_NODATARESPONSE"]._serialized_start = 935
    _globals["_NODATARESPONSE"]._serialized_end = 981
    _globals["_STATUSRESPROLEA2BMASTER"]._serialized_start = 984
    _globals["_STATUSRESPROLEA2BMASTER"]._serialized_end = 1229
    _globals["_STATUSRESPROLEA2BMASTER_A2BFAULT"]._serialized_start = 1101
    _globals["_STATUSRESPROLEA2BMASTER_A2BFAULT"]._serialized_end = 1215
    _globals["_STATUSRESPROLEA2BSLAVE"]._serialized_start = 1231
    _globals["_STATUSRESPROLEA2BSLAVE"]._serialized_end = 1290
    _globals["_STATUSRESPONSE"]._serialized_start = 1293
    _globals["_STATUSRESPONSE"]._serialized_end = 1616
    _globals["_INFORESPONSE"]._serialized_start = 1618
    _globals["_INFORESPONSE"]._serialized_end = 1709
    _globals["_POSITIVERESPONSE"]._serialized_start = 1712
    _globals["_POSITIVERESPONSE"]._serialized_end = 2005
    _globals["_NEGATIVERESPONSE"]._serialized_start = 2007
    _globals["_NEGATIVERESPONSE"]._serialized_end = 2078
    _globals["_REQUESTPACKET"]._serialized_start = 2081
    _globals["_REQUESTPACKET"]._serialized_end = 2460
    _globals["_RESPONSEPACKET"]._serialized_start = 2462
    _globals["_RESPONSEPACKET"]._serialized_end = 2586
# @@protoc_insertion_point(module_scope)
